@@ -5,12 +5,12 @@ import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 from advpowcommon.ui.Cachers import DITPixbufCacher
 from advpowcommon.ui.Animation import DITPBCachedAnimator
-from ifaceswlib.interfaces.GSM import GSMInterface
-from ifaceswlib.interfaces.BT import BTInterface
-from ifaceswlib.interfaces.FlightMode import FlightMode
-from ifaceswlib.interfaces.WLAN import WLANInterface
-from ifaceswlib.util.config import *
-from ifaceswlib.util.locale import *
+from advifswlib.interfaces.GSM import GSMInterface
+from advifswlib.interfaces.BT import BTInterface
+from advifswlib.interfaces.FlightMode import FlightMode
+from advifswlib.interfaces.WLAN import WLANInterface
+from advifswlib.util.config import *
+from advifswlib.util.locale import *
 
 class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
@@ -69,4 +69,4 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
   def __set_sai(self, key):
     self.set_status_area_icon(self.__sai_cacher.get(key))
 
-def get_hd_plugin_type(): return InterfaceSwitcherMaemo5
+def get_hd_plugin_type(): return AdvancedInterfaceSwitcherMaemo5
